@@ -14,6 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 from botocore.paginate import Paginator as Boto3Paginator
 
@@ -214,6 +215,7 @@ class CodeDeployClient:
     [CodeDeploy.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codedeploy.html#CodeDeploy.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def add_tags_to_on_premises_instances(
